"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateDateTime = exports.validateDate = exports.validateTime = void 0;
const leapYear = (year) => {
    return (year % 4 === 0 && year % 100 !== 0) || year % 400 === 0;
};
exports.validateTime = (time) => {
    const TIME_REGEX = /^([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9])(\.\d{1,})?(([Z])|([+|-]([01][0-9]|2[0-3]):[0-5][0-9]))$/;
    return TIME_REGEX.test(time);
};
exports.validateDate = (dateString) => {
    const RFC_3339_REGEX = /^(\d{4}-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01]))$/;
    if (!RFC_3339_REGEX.test(dateString)) {
        return false;
    }
    const year = Number(dateString.substr(0, 4));
    const month = Number(dateString.substr(5, 2));
    const day = Number(dateString.substr(8, 2));
    switch (month) {
        case 2:
            if (leapYear(year) && day > 29) {
                return false;
            }
            else if (!leapYear(year) && day > 28) {
                return false;
            }
            return true;
        case 4:
        case 6:
        case 9:
        case 11:
            if (day > 30) {
                return false;
            }
            break;
    }
    return true;
};
exports.validateDateTime = (dateTimeString) => {
    const RFC_3339_REGEX = /^(\d{4}-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01])T([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60))(\.\d{1,})?(([Z])|([+|-]([01][0-9]|2[0-3]):[0-5][0-9]))$/;
    if (!RFC_3339_REGEX.test(dateTimeString)) {
        return false;
    }
    const time = Date.parse(dateTimeString);
    if (Number.isNaN(time)) {
        return false;
    }
    const index = dateTimeString.indexOf('T');
    const dateString = dateTimeString.substr(0, index);
    const timeString = dateTimeString.substr(index + 1);
    return exports.validateDate(dateString) && exports.validateTime(timeString);
};
//# sourceMappingURL=dateTimeValidation.js.map