"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateTimeUtcToIso = void 0;
const graphql_1 = require("graphql");
const graphql_scalars_1 = require("graphql-scalars");
const dateTimeValidation_1 = require("../dateTimeValidation");
function isoToUtc(isoString) {
    return isoString.substring(0, isoString.length - 5);
}
exports.DateTimeUtcToIso = new graphql_1.GraphQLScalarType({
    name: 'DateTime',
    description: 'UTC DateTime to ISO RFC 3339',
    serialize(value) {
        return graphql_scalars_1.DateTimeResolver.serialize.call(this, `${value}Z`).toISOString();
    },
    parseValue(value) {
        if (!(typeof value === 'string')) {
            throw new TypeError(`DateTime cannot represent non string type ${JSON.stringify(value)}`);
        }
        if (!dateTimeValidation_1.validateDateTime(value)) {
            throw new TypeError(`DateTime cannot represent an invalid date-time-string ${value}.`);
        }
        return isoToUtc(value);
    },
    parseLiteral(ast) {
        if (ast.kind !== graphql_1.Kind.STRING) {
            throw new TypeError(`DateTime cannot represent non string type ${'value' in ast && ast.value}`);
        }
        const { value } = ast;
        if (!dateTimeValidation_1.validateDateTime(value)) {
            throw new TypeError(`DateTime cannot represent an invalid date-time-string ${String(value)}.`);
        }
        return isoToUtc(value);
    }
});
//# sourceMappingURL=DateTimeUtcToIso.js.map